@@ -31,6 +31,7 @@
 #include "locks-table.h"
 #include "lock-tokens-table.h"
 
+#include "private/svn_fs_util.h"
 
 
 int
@@ -44,9 +45,9 @@ svn_fs_bdb__open_locks_table(DB **locks_p,
 
   BDB_ERR(svn_fs_bdb__check_version());
   BDB_ERR(db_create(&locks, env, 0));
-  error = locks->open(SVN_BDB_OPEN_PARAMS(locks, NULL),
-                      "locks", 0, DB_BTREE,
-                      open_flags, 0666);
+  error = (locks->open)(SVN_BDB_OPEN_PARAMS(locks, NULL),
+                        "locks", 0, DB_BTREE,
+                        open_flags, 0666);
 
   /* Create the table if it doesn't yet exist.  This is a form of
      automagical repository upgrading. */
@@ -102,7 +103,7 @@ svn_fs_bdb__lock_delete(svn_fs_t *fs,
   svn_fs_base__str_to_dbt(&key, lock_token);
   svn_fs_base__trail_debug(trail, "locks", "del");
   db_err = bfd->locks->del(bfd->locks, trail->db_txn, &key, 0);
-  
+
   if (db_err == DB_NOTFOUND)
     return svn_fs_base__err_bad_lock_token(fs, lock_token);
   SVN_ERR(BDB_WRAP(fs, "deleting lock from 'locks' table", db_err));
@@ -148,7 +149,7 @@ svn_fs_bdb__lock_get(svn_lock_t **lock_p,
   if (lock->expiration_date && (apr_time_now() > lock->expiration_date))
     {
       SVN_ERR(svn_fs_bdb__lock_delete(fs, lock_token, trail, pool));
-      return svn_fs_base__err_lock_expired(fs, lock_token); 
+      return SVN_FS__ERR_LOCK_EXPIRED(fs, lock_token);
     }
 
   *lock_p = lock;
@@ -195,7 +196,7 @@ svn_fs_bdb__locks_get(svn_fs_t *fs,
   base_fs_data_t *bfd = fs->fsap_data;
   DBC *cursor;
   DBT key, value;
-  int db_err;
+  int db_err, db_c_err;
   apr_pool_t *subpool = svn_pool_create(pool);
   const char *lock_token;
   svn_lock_t *lock;
@@ -227,7 +228,7 @@ svn_fs_bdb__locks_get(svn_fs_t *fs,
 
   svn_fs_base__trail_debug(trail, "lock-tokens", "cursor");
   db_err = bfd->lock_tokens->cursor(bfd->lock_tokens, trail->db_txn,
-                                    &cursor, 0);  
+                                    &cursor, 0);
   SVN_ERR(BDB_WRAP(fs, "creating cursor for reading lock tokens", db_err));
 
   /* Since the key is going to be returned as well as the value make
@@ -237,19 +238,19 @@ svn_fs_bdb__locks_get(svn_fs_t *fs,
 
   /* Get the first matching key that is either equal or greater than
      the one passed in, by passing in the DB_RANGE_SET flag.  */
-  db_err = cursor->c_get(cursor, &key, svn_fs_base__result_dbt(&value),
-                         DB_SET_RANGE);
+  db_err = svn_bdb_dbc_get(cursor, &key, svn_fs_base__result_dbt(&value),
+                           DB_SET_RANGE);
 
   /* As long as the prefix of the returned KEY matches LOOKUP_PATH we
      know it is either LOOKUP_PATH or a decendant thereof.  */
-  while ((! db_err) 
+  while ((! db_err)
          && strncmp(lookup_path, key.data, strlen(lookup_path)) == 0)
     {
       const char *child_path;
 
       svn_pool_clear(subpool);
 
-      svn_fs_base__track_dbt(&key, subpool);      
+      svn_fs_base__track_dbt(&key, subpool);
       svn_fs_base__track_dbt(&value, subpool);
 
       /* Create a usable path and token in temporary memory. */
@@ -260,7 +261,7 @@ svn_fs_bdb__locks_get(svn_fs_t *fs,
       err = get_lock(&lock, fs, child_path, lock_token, trail, subpool);
       if (err)
         {
-          cursor->c_close(cursor);
+          svn_bdb_dbc_close(cursor);
           return err;
         }
 
@@ -270,21 +271,23 @@ svn_fs_bdb__locks_get(svn_fs_t *fs,
           err = get_locks_func(get_locks_baton, lock, subpool);
           if (err)
             {
-              cursor->c_close(cursor);
+              svn_bdb_dbc_close(cursor);
               return err;
             }
         }
 
       svn_fs_base__result_dbt(&key);
       svn_fs_base__result_dbt(&value);
-      db_err = cursor->c_get(cursor, &key, &value, DB_NEXT);
+      db_err = svn_bdb_dbc_get(cursor, &key, &value, DB_NEXT);
     }
 
   svn_pool_destroy(subpool);
-  cursor->c_close(cursor);
+  db_c_err = svn_bdb_dbc_close(cursor);
 
-  if (db_err && (db_err != DB_NOTFOUND)) 
+  if (db_err && (db_err != DB_NOTFOUND))
     SVN_ERR(BDB_WRAP(fs, "fetching lock tokens", db_err));
+  if (db_c_err)
+    SVN_ERR(BDB_WRAP(fs, "fetching lock tokens (closing cursor)", db_c_err));
 
   return SVN_NO_ERROR;
 }
