@@ -2,7 +2,7 @@
  * log.h :  interfaces for running .svn/log files.
  *
  * ====================================================================
- * Copyright (c) 2000-2006 CollabNet.  All rights reserved.
+ * Copyright (c) 2000-2007 CollabNet.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -43,10 +43,21 @@ const char *svn_wc__logfile_path(int log_number,
                                  apr_pool_t *pool);
 
 
-/* Extend **LOG_ACCUM with log instructions to append the contents
-   of SRC to DST.
+
+/* The svn_wc__loggy_* functions in this section take path arguments
+   with the same base as with which the adm_access was opened.
+
 */
 
+/* Extend **LOG_ACCUM with log instructions to append the contents
+   of SRC to DST.
+
+   This command fails to be idempotent or atomic: there's no way to
+   tell if you should re-run this!  This function is deprecated; new
+   uses should not be added, and the single current use (constructing
+   human-readable non-parsed property conflict files) should be
+   rewritten.  See Issue #3015.
+*/
 svn_error_t *
 svn_wc__loggy_append(svn_stringbuf_t **log_accum,
                      svn_wc_adm_access_t *adm_access,
@@ -57,7 +68,6 @@ svn_wc__loggy_append(svn_stringbuf_t **log_accum,
 /* Extend **LOG_ACCUM with log instructions to mark PATH as committed
    with revision REVNUM.
 */
-
 svn_error_t *
 svn_wc__loggy_committed(svn_stringbuf_t **log_accum,
                         svn_wc_adm_access_t *adm_access,
@@ -87,7 +97,6 @@ typedef enum svn_wc__copy_t
   svn_wc__copy_detranslate
 } svn_wc__copy_t;
 
-
 svn_error_t *
 svn_wc__loggy_copy(svn_stringbuf_t **log_accum,
                    svn_boolean_t *dst_modified,
@@ -102,7 +111,6 @@ svn_wc__loggy_copy(svn_stringbuf_t **log_accum,
    file from SRC to DST with translation settings from VERSIONED
    and flags specified in FLAGS.
 */
-
 svn_error_t *
 svn_wc__loggy_translated_file(svn_stringbuf_t **log_accum,
                               svn_wc_adm_access_t *adm_access,
@@ -124,13 +132,20 @@ svn_wc__loggy_delete_entry(svn_stringbuf_t **log_accum,
 /* Extend **LOG_ACCUM with log instructions to delete lock related
    fields from the entry belonging to PATH.
 */
-
 svn_error_t *
 svn_wc__loggy_delete_lock(svn_stringbuf_t **log_accum,
                           svn_wc_adm_access_t *adm_access,
                           const char *path,
                           apr_pool_t *pool);
 
+/* Extend **LOG_ACCUM with log instructions to delete changelist
+   from the entry belonging to PATH.
+*/
+svn_error_t *
+svn_wc__loggy_delete_changelist(svn_stringbuf_t **log_accum,
+                                svn_wc_adm_access_t *adm_access,
+                                const char *path,
+                                apr_pool_t *pool);
 
 /* Extend **LOG_ACCUM with commands to modify the entry associated with NAME
    according to the flags specified in MODIFY_FLAGS, based on the values
@@ -144,13 +159,12 @@ svn_wc__loggy_entry_modify(svn_stringbuf_t **log_accum,
                            svn_wc_adm_access_t *adm_access,
                            const char *name,
                            svn_wc_entry_t *entry,
-                           apr_uint32_t modify_flags,
+                           apr_uint64_t modify_flags,
                            apr_pool_t *pool);
 
 /* Extend **LOG_ACCUM with log instructions to modify wcprop PROPNAME
    for PATH, setting it to PROPVAL.
 */
-
 svn_error_t *
 svn_wc__loggy_modify_wcprop(svn_stringbuf_t **log_accum,
                             svn_wc_adm_access_t *adm_access,
@@ -159,21 +173,6 @@ svn_wc__loggy_modify_wcprop(svn_stringbuf_t **log_accum,
                             const char *propval,
                             apr_pool_t *pool);
 
-/* Extend **LOG_ACCUM with log instructions to merge changes between
-   LEFT and RIGHT into TARGET, marking conflicts with the appropriate labels.
-*/
-
-svn_error_t *
-svn_wc__loggy_merge(svn_stringbuf_t **log_accum,
-                    svn_wc_adm_access_t *adm_access,
-                    const char *target,
-                    const char *left,
-                    const char *right,
-                    const char *left_label,
-                    const char *right_label,
-                    const char *target_label,
-                    apr_pool_t *pool);
-
 
 /* Extend **LOG_ACCUM with log instructions to move the file SRC_PATH to
    DST_PATH, if it exists. If it doesn't and REMOVE_DST_IF_NO_SRC is TRUE
@@ -181,7 +180,6 @@ svn_wc__loggy_merge(svn_stringbuf_t **log_accum,
 
    Sets *DST_MODIFIED, if either the copy or the remove have been carried out.
 */
-
 svn_error_t *
 svn_wc__loggy_move(svn_stringbuf_t **log_accum,
                    svn_boolean_t *dst_modified,
@@ -195,7 +193,6 @@ svn_wc__loggy_move(svn_stringbuf_t **log_accum,
 /* Extend **LOG_ACCUM with log instructions to set permissions of PATH
    to 'executable' if it has the 'executable' property set.
 */
-
 svn_error_t *
 svn_wc__loggy_maybe_set_executable(svn_stringbuf_t **log_accum,
                                    svn_wc_adm_access_t *adm_access,
@@ -206,7 +203,6 @@ svn_wc__loggy_maybe_set_executable(svn_stringbuf_t **log_accum,
    to 'readonly' if it has the 'needs-lock' property set and there is
    no lock for the file in the working copy.
 */
-
 svn_error_t *
 svn_wc__loggy_maybe_set_readonly(svn_stringbuf_t **log_accum,
                                  svn_wc_adm_access_t *adm_access,
@@ -219,7 +215,6 @@ svn_wc__loggy_maybe_set_readonly(svn_stringbuf_t **log_accum,
 
    Use SVN_WC__ENTRY_ATTR_* values for TIME_PROP.
 */
-
 svn_error_t *
 svn_wc__loggy_set_entry_timestamp_from_wc(svn_stringbuf_t **log_accum,
                                           svn_wc_adm_access_t *adm_access,
@@ -227,10 +222,20 @@ svn_wc__loggy_set_entry_timestamp_from_wc(svn_stringbuf_t **log_accum,
                                           const char *time_prop,
                                           apr_pool_t *pool);
 
+
+/* Extend **LOG_ACCUM with log instructions to set the file size of PATH
+   in the entries' WORKING_SIZE field.
+*/
+svn_error_t *
+svn_wc__loggy_set_entry_working_size_from_wc(svn_stringbuf_t **log_accum,
+                                             svn_wc_adm_access_t *adm_access,
+                                             const char *path,
+                                             apr_pool_t *pool);
+
+
 /* Extend **LOG_ACCUM with log instructions to set permissions of PATH
    to 'readonly'.
 */
-
 svn_error_t *
 svn_wc__loggy_set_readonly(svn_stringbuf_t **log_accum,
                            svn_wc_adm_access_t *adm_access,
@@ -253,7 +258,7 @@ svn_wc__loggy_set_timestamp(svn_stringbuf_t **log_accum,
 svn_error_t *
 svn_wc__loggy_remove(svn_stringbuf_t **log_accum,
                      svn_wc_adm_access_t *adm_access,
-                     const char *base_name,
+                     const char *path,
                      apr_pool_t *pool);
 
 /* Extend **LOG_ACCUM with instructions to cause the working copy of ADM_ACCESS
@@ -276,7 +281,7 @@ svn_wc__write_log(svn_wc_adm_access_t *adm_access,
                   apr_pool_t *pool);
 
 
-/* Process the instructions in the log file for ADM_ACCESS. 
+/* Process the instructions in the log file for ADM_ACCESS.
    DIFF3_CMD is the external differ used by the 'SVN_WC__LOG_MERGE'
    log entry.  It is always safe to pass null for this.
 
