@@ -29,7 +29,8 @@
 #include "svn_delta.h"
 #include "svn_pools.h"
 #include "svn_error.h"
-#include "svn_test.h"
+
+#include "../svn_test.h"
 
 #include "../../libsvn_delta/delta.h"
 #include "delta-window-test.h"
@@ -47,12 +48,12 @@
 extern int test_argc;
 extern const char **test_argv;
 
-static void init_params (apr_uint32_t *seed,
-                         apr_uint32_t *maxlen, int *iterations,
-                         int *dump_files, int *print_windows,
-                         const char **random_bytes,
-                         apr_uint32_t *bytes_range,
-                         apr_pool_t *pool)
+static void init_params(apr_uint32_t *seed,
+                        apr_uint32_t *maxlen, int *iterations,
+                        int *dump_files, int *print_windows,
+                        const char **random_bytes,
+                        apr_uint32_t *bytes_range,
+                        apr_pool_t *pool)
 {
   apr_getopt_t *opt;
   char optch;
@@ -67,24 +68,24 @@ static void init_params (apr_uint32_t *seed,
   *random_bytes = NULL;
   *bytes_range = 256;
 
-  apr_getopt_init (&opt, pool, test_argc, test_argv);
+  apr_getopt_init(&opt, pool, test_argc, test_argv);
   while (APR_SUCCESS
-         == (status = apr_getopt (opt, "s:l:n:r:FW", &optch, &opt_arg)))
+         == (status = apr_getopt(opt, "s:l:n:r:FW", &optch, &opt_arg)))
     {
       switch (optch)
         {
         case 's':
-          *seed = atol (opt_arg);
+          *seed = atol(opt_arg);
           break;
         case 'l':
-          *maxlen = atoi (opt_arg);
+          *maxlen = atoi(opt_arg);
           break;
         case 'n':
-          *iterations = atoi (opt_arg);
+          *iterations = atoi(opt_arg);
           break;
         case 'r':
           *random_bytes = opt_arg + 1;
-          *bytes_range = strlen (*random_bytes);
+          *bytes_range = strlen(*random_bytes);
           break;
         case 'F':
           *dump_files = !*dump_files;
@@ -99,50 +100,50 @@ static void init_params (apr_uint32_t *seed,
 
 /* Open a temporary file. */
 static apr_file_t *
-open_tempfile (const char *name_template, apr_pool_t *pool)
+open_tempfile(const char *name_template, apr_pool_t *pool)
 {
   apr_status_t apr_err;
   apr_file_t *fp = NULL;
   char *templ;
 
   if (!name_template)
-    templ = apr_pstrdup (pool, "tempfile_XXXXXX");
+    templ = apr_pstrdup(pool, "tempfile_XXXXXX");
   else
-    templ = apr_pstrdup (pool, name_template);
+    templ = apr_pstrdup(pool, name_template);
 
-  apr_err = apr_file_mktemp (&fp, templ, 0, pool);
-  assert (apr_err == 0);
-  assert (fp != NULL);
+  apr_err = apr_file_mktemp(&fp, templ, 0, pool);
+  assert(apr_err == 0);
+  assert(fp != NULL);
   return fp;
 }
 
 /* Rewind the file pointer */
-static void rewind_file (apr_file_t *fp)
+static void rewind_file(apr_file_t *fp)
 {
   apr_off_t offset = 0;
 #ifndef NDEBUG
   apr_status_t apr_err =
 #endif
-    apr_file_seek (fp, APR_SET, &offset);
-  assert (apr_err == 0);
-  assert (offset == 0);
+    apr_file_seek(fp, APR_SET, &offset);
+  assert(apr_err == 0);
+  assert(offset == 0);
 }
 
 
 static void
-dump_file_contents (apr_file_t *fp)
+dump_file_contents(apr_file_t *fp)
 {
   static char file_buffer[10240];
   apr_size_t length = sizeof file_buffer;
-  fputs ("--------\n", stdout);
+  fputs("--------\n", stdout);
   do
     {
-      apr_file_read_full (fp, file_buffer, sizeof file_buffer, &length);
-      fwrite (file_buffer, 1, length, stdout);
+      apr_file_read_full(fp, file_buffer, sizeof file_buffer, &length);
+      fwrite(file_buffer, 1, length, stdout);
     }
   while (length == sizeof file_buffer);
-  putc ('\n', stdout);
-  rewind_file (fp);
+  putc('\n', stdout);
+  rewind_file(fp);
 }
 
 /* Generate a temporary file containing sort-of random data.  Diffs
@@ -150,13 +151,13 @@ dump_file_contents (apr_file_t *fp)
    make sure there are a bunch of common substrings between two runs
    of this function with the same seedbase.  */
 static apr_file_t *
-generate_random_file (apr_uint32_t maxlen,
-                      apr_uint32_t subseed_base,
-                      apr_uint32_t *seed,
-                      const char *random_bytes,
-                      apr_uint32_t bytes_range,
-                      int dump_files,
-                      apr_pool_t *pool)
+generate_random_file(apr_uint32_t maxlen,
+                     apr_uint32_t subseed_base,
+                     apr_uint32_t *seed,
+                     const char *random_bytes,
+                     apr_uint32_t bytes_range,
+                     int dump_files,
+                     apr_pool_t *pool)
 {
   static char file_buffer[10240];
   char *buf = file_buffer;
@@ -166,8 +167,8 @@ generate_random_file (apr_uint32_t maxlen,
   apr_file_t *fp;
   unsigned long r;
 
-  fp = open_tempfile ("random_XXXXXX", pool);
-  len = svn_test_rand (seed) % maxlen; /* We might go over this by a bit.  */
+  fp = open_tempfile("random_XXXXXX", pool);
+  len = svn_test_rand(seed) % maxlen; /* We might go over this by a bit.  */
   while (len > 0)
     {
       /* Generate a pseudo-random sequence of up to MAXSEQ bytes,
@@ -175,10 +176,10 @@ generate_random_file (apr_uint32_t maxlen,
          (Use our own pseudo-random number generator here to avoid
          clobbering the seed of the libc random number generator.)  */
 
-      seqlen = svn_test_rand (seed) % MAXSEQ;
+      seqlen = svn_test_rand(seed) % MAXSEQ;
       if (seqlen > len) seqlen = len;
       len -= seqlen;
-      r = subseed_base + svn_test_rand (seed) % SEEDS;
+      r = subseed_base + svn_test_rand(seed) % SEEDS;
       while (seqlen-- > 0)
         {
           const int ch = (random_bytes
@@ -187,8 +188,8 @@ generate_random_file (apr_uint32_t maxlen,
           if (buf == end)
             {
               apr_size_t ignore_length;
-              apr_file_write_full (fp, file_buffer, sizeof file_buffer,
-                                   &ignore_length);
+              apr_file_write_full(fp, file_buffer, sizeof file_buffer,
+                                  &ignore_length);
               buf = file_buffer;
             }
 
@@ -200,20 +201,20 @@ generate_random_file (apr_uint32_t maxlen,
   if (buf > file_buffer)
     {
       apr_size_t ignore_length;
-      apr_file_write_full (fp, file_buffer, buf - file_buffer, &ignore_length);
+      apr_file_write_full(fp, file_buffer, buf - file_buffer, &ignore_length);
       buf = file_buffer;
     }
-  rewind_file (fp);
+  rewind_file(fp);
 
   if (dump_files)
-    dump_file_contents (fp);
+    dump_file_contents(fp);
 
   return fp;
 }
 
 /* Compare two open files. The file positions may change. */
 static svn_error_t *
-compare_files (apr_file_t *f1, apr_file_t *f2, int dump_files)
+compare_files(apr_file_t *f1, apr_file_t *f2, int dump_files)
 {
   static char file_buffer_1[10240];
   static char file_buffer_2[10240];
@@ -222,11 +223,11 @@ compare_files (apr_file_t *f1, apr_file_t *f2, int dump_files)
   apr_off_t pos = 0;
   apr_size_t len1, len2;
 
-  rewind_file (f1);
-  rewind_file (f2);
+  rewind_file(f1);
+  rewind_file(f2);
 
   if (dump_files)
-    dump_file_contents (f2);
+    dump_file_contents(f2);
 
   do
     {
@@ -238,15 +239,15 @@ compare_files (apr_file_t *f1, apr_file_t *f2, int dump_files)
            ++c1, ++c2, ++pos)
         {
           if (*c1 != *c2)
-            return svn_error_createf (SVN_ERR_TEST_FAILED, NULL,
-                                      "mismatch at position %"APR_OFF_T_FMT,
-                                      pos);
+            return svn_error_createf(SVN_ERR_TEST_FAILED, NULL,
+                                     "mismatch at position %"APR_OFF_T_FMT,
+                                     pos);
         }
 
       if (len1 != len2)
-        return svn_error_createf (SVN_ERR_TEST_FAILED, NULL,
-                                  "unequal file sizes at position"
-                                  " %"APR_OFF_T_FMT, pos);
+        return svn_error_createf(SVN_ERR_TEST_FAILED, NULL,
+                                 "unequal file sizes at position"
+                                 " %"APR_OFF_T_FMT, pos);
     }
   while (len1 == sizeof file_buffer_1);
   return SVN_NO_ERROR;
@@ -254,35 +255,36 @@ compare_files (apr_file_t *f1, apr_file_t *f2, int dump_files)
 
 
 static apr_file_t *
-copy_tempfile (apr_file_t *fp, apr_pool_t *pool)
+copy_tempfile(apr_file_t *fp, apr_pool_t *pool)
 {
   static char file_buffer[10240];
   apr_file_t *newfp;
   apr_size_t length1, length2;
 
-  newfp = open_tempfile ("copy_XXXXXX", pool);
+  newfp = open_tempfile("copy_XXXXXX", pool);
 
-  rewind_file (fp);
+  rewind_file(fp);
   do
     {
-      apr_file_read_full (fp, file_buffer, sizeof file_buffer, &length1);
-      apr_file_write_full (newfp, file_buffer, length1, &length2);
-      assert (length1 == length2);
+      apr_file_read_full(fp, file_buffer, sizeof file_buffer, &length1);
+      apr_file_write_full(newfp, file_buffer, length1, &length2);
+      assert(length1 == length2);
     }
   while (length1 == sizeof file_buffer);
 
-  rewind_file (fp);
-  rewind_file (newfp);
+  rewind_file(fp);
+  rewind_file(newfp);
   return newfp;
 }
 
 
 
+/* Implements svn_test_driver_t. */
 static svn_error_t *
-random_test (const char **msg,
-             svn_boolean_t msg_only,
-             svn_test_opts_t *opts,
-             apr_pool_t *pool)
+random_test(const char **msg,
+            svn_boolean_t msg_only,
+            svn_test_opts_t *opts,
+            apr_pool_t *pool)
 {
   static char msg_buff[256];
 
@@ -305,15 +307,15 @@ random_test (const char **msg,
   for (i = 0; i < iterations; i++)
     {
       /* Generate source and target for the delta and its application.  */
-      apr_uint32_t subseed_base = svn_test_rand (&seed);
-      apr_file_t *source = generate_random_file (maxlen, subseed_base, &seed,
-                                                 random_bytes, bytes_range,
-                                                 dump_files, pool);
-      apr_file_t *target = generate_random_file (maxlen, subseed_base, &seed,
-                                                 random_bytes, bytes_range,
-                                                 dump_files, pool);
-      apr_file_t *source_copy = copy_tempfile (source, pool);
-      apr_file_t *target_regen = open_tempfile (NULL, pool);
+      apr_uint32_t subseed_base = svn_test_rand(&seed);
+      apr_file_t *source = generate_random_file(maxlen, subseed_base, &seed,
+                                                random_bytes, bytes_range,
+                                                dump_files, pool);
+      apr_file_t *target = generate_random_file(maxlen, subseed_base, &seed,
+                                                random_bytes, bytes_range,
+                                                dump_files, pool);
+      apr_file_t *source_copy = copy_tempfile(source, pool);
+      apr_file_t *target_regen = open_tempfile(NULL, pool);
 
       svn_txdelta_stream_t *txdelta_stream;
       svn_txdelta_window_handler_t handler;
@@ -324,39 +326,40 @@ random_test (const char **msg,
          svndiff format, parse it back into delta format, and apply it
          to a copy of the source file to see if we get the same target
          back.  */
-      apr_pool_t *delta_pool = svn_pool_create (pool);
+      apr_pool_t *delta_pool = svn_pool_create(pool);
 
       /* Make stage 4: apply the text delta.  */
-      svn_txdelta_apply (svn_stream_from_aprfile (source_copy, delta_pool),
-                         svn_stream_from_aprfile (target_regen, delta_pool),
-                         NULL, NULL, delta_pool, &handler, &handler_baton);
+      svn_txdelta_apply(svn_stream_from_aprfile(source_copy, delta_pool),
+                        svn_stream_from_aprfile(target_regen, delta_pool),
+                        NULL, NULL, delta_pool, &handler, &handler_baton);
 
       /* Make stage 3: reparse the text delta.  */
-      stream = svn_txdelta_parse_svndiff (handler, handler_baton, TRUE,
-                                          delta_pool);
+      stream = svn_txdelta_parse_svndiff(handler, handler_baton, TRUE,
+                                         delta_pool);
 
       /* Make stage 2: encode the text delta in svndiff format.  */
-      svn_txdelta_to_svndiff (stream, delta_pool, &handler, &handler_baton);
+      svn_txdelta_to_svndiff2(&handler, &handler_baton, stream, 1,
+                              delta_pool);
 
       /* Make stage 1: create the text delta.  */
-      svn_txdelta (&txdelta_stream,
-                   svn_stream_from_aprfile (source, delta_pool),
-                   svn_stream_from_aprfile (target, delta_pool),
-                   delta_pool);
+      svn_txdelta(&txdelta_stream,
+                  svn_stream_from_aprfile(source, delta_pool),
+                  svn_stream_from_aprfile(target, delta_pool),
+                  delta_pool);
 
-      SVN_ERR (svn_txdelta_send_txstream (txdelta_stream,
-                                          handler,
-                                          handler_baton,
-                                          delta_pool));
+      SVN_ERR(svn_txdelta_send_txstream(txdelta_stream,
+                                        handler,
+                                        handler_baton,
+                                        delta_pool));
 
-      svn_pool_destroy (delta_pool);
+      svn_pool_destroy(delta_pool);
 
-      SVN_ERR (compare_files (target, target_regen, dump_files));
+      SVN_ERR(compare_files(target, target_regen, dump_files));
 
-      apr_file_close (source);
-      apr_file_close (target);
-      apr_file_close (source_copy);
-      apr_file_close (target_regen);
+      apr_file_close(source);
+      apr_file_close(target);
+      apr_file_close(source_copy);
+      apr_file_close(target_regen);
     }
 
   return SVN_NO_ERROR;
@@ -364,11 +367,12 @@ random_test (const char **msg,
 
 
 
+/* (Note: *LAST_SEED is an output parameter.) */
 static svn_error_t *
-do_random_combine_test (const char **msg,
-                        svn_boolean_t msg_only,
-                        apr_pool_t *pool,
-                        apr_uint32_t *last_seed)
+do_random_combine_test(const char **msg,
+                       svn_boolean_t msg_only,
+                       apr_pool_t *pool,
+                       apr_uint32_t *last_seed)
 {
   static char msg_buff[256];
 
@@ -392,19 +396,19 @@ do_random_combine_test (const char **msg,
   for (i = 0; i < iterations; i++)
     {
       /* Generate source and target for the delta and its application.  */
-      apr_uint32_t subseed_base = svn_test_rand ((*last_seed = seed, &seed));
-      apr_file_t *source = generate_random_file (maxlen, subseed_base, &seed,
-                                                 random_bytes, bytes_range,
-                                                 dump_files, pool);
-      apr_file_t *middle = generate_random_file (maxlen, subseed_base, &seed,
-                                                 random_bytes, bytes_range,
-                                                 dump_files, pool);
-      apr_file_t *target = generate_random_file (maxlen, subseed_base, &seed,
-                                                 random_bytes, bytes_range,
-                                                 dump_files, pool);
-      apr_file_t *source_copy = copy_tempfile (source, pool);
-      apr_file_t *middle_copy = copy_tempfile (middle, pool);
-      apr_file_t *target_regen = open_tempfile (NULL, pool);
+      apr_uint32_t subseed_base = svn_test_rand((*last_seed = seed, &seed));
+      apr_file_t *source = generate_random_file(maxlen, subseed_base, &seed,
+                                                random_bytes, bytes_range,
+                                                dump_files, pool);
+      apr_file_t *middle = generate_random_file(maxlen, subseed_base, &seed,
+                                                random_bytes, bytes_range,
+                                                dump_files, pool);
+      apr_file_t *target = generate_random_file(maxlen, subseed_base, &seed,
+                                                random_bytes, bytes_range,
+                                                dump_files, pool);
+      apr_file_t *source_copy = copy_tempfile(source, pool);
+      apr_file_t *middle_copy = copy_tempfile(middle, pool);
+      apr_file_t *target_regen = open_tempfile(NULL, pool);
 
       svn_txdelta_stream_t *txdelta_stream_A;
       svn_txdelta_stream_t *txdelta_stream_B;
@@ -416,61 +420,62 @@ do_random_combine_test (const char **msg,
          and convert the result to svndiff format, parse that back
          into delta format, and apply it to a copy of the source file
          to see if we get the same target back.  */
-      apr_pool_t *delta_pool = svn_pool_create (pool);
+      apr_pool_t *delta_pool = svn_pool_create(pool);
 
       /* Make stage 4: apply the text delta.  */
-      svn_txdelta_apply (svn_stream_from_aprfile (source_copy, delta_pool),
-                         svn_stream_from_aprfile (target_regen, delta_pool),
-                         NULL, NULL, delta_pool, &handler, &handler_baton);
+      svn_txdelta_apply(svn_stream_from_aprfile(source_copy, delta_pool),
+                        svn_stream_from_aprfile(target_regen, delta_pool),
+                        NULL, NULL, delta_pool, &handler, &handler_baton);
 
       /* Make stage 3: reparse the text delta.  */
-      stream = svn_txdelta_parse_svndiff (handler, handler_baton, TRUE,
-                                          delta_pool);
+      stream = svn_txdelta_parse_svndiff(handler, handler_baton, TRUE,
+                                         delta_pool);
 
       /* Make stage 2: encode the text delta in svndiff format.  */
-      svn_txdelta_to_svndiff (stream, delta_pool, &handler, &handler_baton);
+      svn_txdelta_to_svndiff2(&handler, &handler_baton, stream, 1,
+                              delta_pool);
 
       /* Make stage 1: create the text deltas.  */
 
-      svn_txdelta (&txdelta_stream_A,
-                   svn_stream_from_aprfile (source, delta_pool),
-                   svn_stream_from_aprfile (middle, delta_pool),
-                   delta_pool);
+      svn_txdelta(&txdelta_stream_A,
+                  svn_stream_from_aprfile(source, delta_pool),
+                  svn_stream_from_aprfile(middle, delta_pool),
+                  delta_pool);
 
-      svn_txdelta (&txdelta_stream_B,
-                   svn_stream_from_aprfile (middle_copy, delta_pool),
-                   svn_stream_from_aprfile (target, delta_pool),
-                   delta_pool);
+      svn_txdelta(&txdelta_stream_B,
+                  svn_stream_from_aprfile(middle_copy, delta_pool),
+                  svn_stream_from_aprfile(target, delta_pool),
+                  delta_pool);
 
       {
         svn_txdelta_window_t *window_A;
         svn_txdelta_window_t *window_B;
         svn_txdelta_window_t *composite;
-        apr_pool_t *wpool = svn_pool_create (delta_pool);
+        apr_pool_t *wpool = svn_pool_create(delta_pool);
 
         do
           {
-            SVN_ERR (svn_txdelta_next_window (&window_A, txdelta_stream_A,
-                                              wpool));
+            SVN_ERR(svn_txdelta_next_window(&window_A, txdelta_stream_A,
+                                            wpool));
             if (print_windows)
-              delta_window_print (window_A, "A ", stdout);
-            SVN_ERR (svn_txdelta_next_window (&window_B, txdelta_stream_B,
-                                              wpool));
+              delta_window_print(window_A, "A ", stdout);
+            SVN_ERR(svn_txdelta_next_window(&window_B, txdelta_stream_B,
+                                            wpool));
             if (print_windows)
-              delta_window_print (window_B, "B ", stdout);
+              delta_window_print(window_B, "B ", stdout);
             if (!window_B)
               break;
-            assert (window_A != NULL || window_B->src_ops == 0);
+            assert(window_A != NULL || window_B->src_ops == 0);
             if (window_B->src_ops == 0)
               {
                 composite = window_B;
                 composite->sview_len = 0;
               }
             else
-              composite = svn_txdelta__compose_windows (window_A, window_B,
-                                                        wpool);
+              composite = svn_txdelta_compose_windows(window_A, window_B,
+                                                      wpool);
             if (print_windows)
-              delta_window_print (composite, "AB", stdout);
+              delta_window_print(composite, "AB", stdout);
 
             /* The source view length should not be 0 if there are
                source copy ops in the window. */
@@ -480,36 +485,37 @@ do_random_combine_test (const char **msg,
                 (SVN_ERR_FS_GENERAL, NULL,
                  "combined delta window is inconsistent");
 
-            SVN_ERR (handler (composite, handler_baton));
-            svn_pool_clear (wpool);
+            SVN_ERR(handler(composite, handler_baton));
+            svn_pool_clear(wpool);
           }
         while (composite != NULL);
-        svn_pool_destroy (wpool);
+        svn_pool_destroy(wpool);
       }
 
-      svn_pool_destroy (delta_pool);
+      svn_pool_destroy(delta_pool);
 
-      SVN_ERR (compare_files (target, target_regen, dump_files));
+      SVN_ERR(compare_files(target, target_regen, dump_files));
 
-      apr_file_close (source);
-      apr_file_close (middle);
-      apr_file_close (target);
-      apr_file_close (source_copy);
-      apr_file_close (middle_copy);
-      apr_file_close (target_regen);
+      apr_file_close(source);
+      apr_file_close(middle);
+      apr_file_close(target);
+      apr_file_close(source_copy);
+      apr_file_close(middle_copy);
+      apr_file_close(target_regen);
     }
 
   return SVN_NO_ERROR;
 }
 
+/* Implements svn_test_driver_t. */
 static svn_error_t *
-random_combine_test (const char **msg,
-                     svn_boolean_t msg_only,
-                     svn_test_opts_t *opts,
-                     apr_pool_t *pool)
+random_combine_test(const char **msg,
+                    svn_boolean_t msg_only,
+                    svn_test_opts_t *opts,
+                    apr_pool_t *pool)
 {
   apr_uint32_t seed;
-  svn_error_t *err = do_random_combine_test (msg, msg_only, pool, &seed);
+  svn_error_t *err = do_random_combine_test(msg, msg_only, pool, &seed);
   if (!msg_only)
     printf("SEED:  Last seen = %lu\n", (unsigned long) seed);
   return err;
@@ -528,10 +534,10 @@ random_combine_test (const char **msg,
 struct svn_test_descriptor_t test_funcs[] =
   {
     SVN_TEST_NULL,
-    SVN_TEST_PASS (random_test),
-    SVN_TEST_PASS (random_combine_test),
+    SVN_TEST_PASS(random_test),
+    SVN_TEST_PASS(random_combine_test),
 #ifdef SVN_RANGE_INDEX_TEST_H
-    SVN_TEST_PASS (random_range_index_test),
+    SVN_TEST_PASS(random_range_index_test),
 #endif
     SVN_TEST_NULL
   };
